@@ -1,3 +1,4 @@
+import glob
 import os
 import unittest
 
@@ -32,41 +33,51 @@ class Run(TestCaseTmpDir):
         test_path = os.path.join(BASEDIR, 'examples',
                                  'tests', 'cit_parameters.py')
         cmd_line = (
-            '{0} --show=test run --disable-sysinfo --job-results-dir={1} '
+            '{0} run --disable-sysinfo --job-results-dir={1} '
             '--cit-order-of-combinations=1 '
             '--cit-parameter-file={2} '
             '-- {3}'
         ).format(AVOCADO, self.tmpdir.name, params_path, test_path)
-        result = process.run(cmd_line)
+        process.run(cmd_line)
+
+        base_test_logs_dir = os.path.join(self.tmpdir.name, 'latest',
+                                          'test-results')
+        test_result_files = glob.glob(os.path.join(base_test_logs_dir,
+                                                   '*', 'debug.log'))
+        all_tests_content = b''
+        for test_result_file in test_result_files:
+            with open(test_result_file, 'r+b') as one_test_result:
+                all_tests_content += one_test_result.read()
+
         # all values should be looked for at least once
         self.assertIn(b"PARAMS (key=color, path=*, default=None) => 'green'",
-                      result.stdout)
+                      all_tests_content)
         # all values of shape should be looked for at least once
         self.assertIn(b"PARAMS (key=shape, path=*, default=None) => 'square'",
-                      result.stdout)
+                      all_tests_content)
         self.assertIn(b"PARAMS (key=shape, path=*, default=None) => 'triangle'",
-                      result.stdout)
+                      all_tests_content)
         self.assertIn(b"PARAMS (key=shape, path=*, default=None) => 'circle'",
-                      result.stdout)
+                      all_tests_content)
         # all values of state should be looked for at least once
         self.assertIn(b"PARAMS (key=state, path=*, default=None) => 'liquid'",
-                      result.stdout)
+                      all_tests_content)
         self.assertIn(b"PARAMS (key=state, path=*, default=None) => 'solid'",
-                      result.stdout)
+                      all_tests_content)
         self.assertIn(b"PARAMS (key=state, path=*, default=None) => 'gas'",
-                      result.stdout)
+                      all_tests_content)
         # all values of material should be looked for at least once
         self.assertIn(b"PARAMS (key=material, path=*, default=None) => 'leather'",
-                      result.stdout)
+                      all_tests_content)
         self.assertIn(b"PARAMS (key=material, path=*, default=None) => 'plastic'",
-                      result.stdout)
+                      all_tests_content)
         self.assertIn(b"PARAMS (key=material, path=*, default=None) => 'aluminum'",
-                      result.stdout)
+                      all_tests_content)
         # all values of coating should be looked for at least once
         self.assertIn(b"PARAMS (key=coating, path=*, default=None) => 'anodic'",
-                      result.stdout)
+                      all_tests_content)
         self.assertIn(b"PARAMS (key=coating, path=*, default=None) => 'cathodic'",
-                      result.stdout)
+                      all_tests_content)
 
 
 if __name__ == '__main__':
